#include <iostream>
#include <queue>
#include <functional>

struct Edge {
    int32_t u, v, t;
};

const int32_t MAX_WEIGHT = 1e6;

int32_t find_ans(const int32_t n, const std::vector<Edge>& e) {
    const int32_t entrance = 0, orthanc = n - 1;

    // Dijkstra algorithm in m log n
    const int64_t INF = static_cast<int64_t>(n) * MAX_WEIGHT;
    std::vector<std::vector<int32_t>> ingoing_arc_indices(n);
    for (int32_t arc_index = 0; arc_index < std::ssize(e); ++arc_index)
        ingoing_arc_indices[e[arc_index].v].push_back(arc_index);
    std::vector<int64_t> distance_to_orthanc(n, INF);
    std::priority_queue<std::pair<int64_t, int32_t>, std::vector<std::pair<int64_t, int32_t>>, std::greater<>> nearest;
    nearest.emplace(0, orthanc);
    distance_to_orthanc[orthanc] = 0;
    while (!nearest.empty()) {
        auto [current_distance_to_orthanc, current_tower] = nearest.top();
        nearest.pop();
        if (current_distance_to_orthanc != distance_to_orthanc[current_tower])
            continue;
        for (int32_t arc_index : ingoing_arc_indices[current_tower]) {
            int32_t another_tower = e[arc_index].u;
            int64_t new_distance_to_orthanc = current_distance_to_orthanc + e[arc_index].t;
            if (new_distance_to_orthanc < distance_to_orthanc[another_tower]) {
                distance_to_orthanc[another_tower] = new_distance_to_orthanc;
                nearest.emplace(new_distance_to_orthanc, another_tower);
            }
        }
    }

    // find effective edges. Ignore too long ones
    std::vector<std::unordered_map<int32_t, int32_t>> outgoing_arc_indices(n);
    for (int32_t arc_index = 0; arc_index < std::ssize(e); ++arc_index) {
        if (e[arc_index].u == e[arc_index].v)
            continue;
        if (!outgoing_arc_indices[e[arc_index].u].contains(e[arc_index].v)) {
            outgoing_arc_indices[e[arc_index].u][e[arc_index].v] = arc_index;
            continue;
        }
        int32_t& old_arc_index = outgoing_arc_indices[e[arc_index].u][e[arc_index].v];
        if (e[arc_index].t < e[old_arc_index].t)
            old_arc_index = arc_index;
    }

    // recursive search
    std::vector<bool> recurse(n);
    std::function<int32_t(int32_t, int32_t)> find_bounded_incompetence = [&](const int32_t tower, int32_t bound) -> int32_t {
        recurse[tower] = true;
        // no way to Orthanc? Instant loss.
        if (distance_to_orthanc[tower] == INF) {
            recurse[tower] = false;
            return -1;
        }
        // already in Orthanc? Instant win.
        if (tower == orthanc) {
            recurse[tower] = false;
            return bound;
        }
        // let us try and spend some incompetence
        bool successful_effective = false;
        for (const auto [to, arc_index] : outgoing_arc_indices[tower]) {
            // incompetence is over? Instant win.
            if (bound == 0) {
                recurse[tower] = false;
                return 0;
            }
            // if already in our path, not worth going in
            if (recurse[to])
                continue;
            // if bad edge, have to spend some incompetence
            int32_t incompetence_delta = 0;
            if (distance_to_orthanc[e[arc_index].u] != distance_to_orthanc[e[arc_index].v] + e[arc_index].t)
                incompetence_delta = 1;
            int32_t remaining_incompetence = bound - incompetence_delta;
            remaining_incompetence = find_bounded_incompetence(to, remaining_incompetence);
            if (remaining_incompetence + 1 < bound) {
                bound = remaining_incompetence + 1;
                successful_effective = false;
            }
            if (incompetence_delta == 1)
                continue;
            if (remaining_incompetence >= bound)
                successful_effective = true;
        }
        if (bound == 0) {
            recurse[tower] = false;
            return 0;
        }
        recurse[tower] = false;
        return bound - !successful_effective;
    };
    return find_bounded_incompetence(entrance, n);
}

void solve_test() {
    int n, m;
    std::cin >> n >> m;
    std::vector<Edge> e(m);
    for (Edge& f : e) {
        std::cin >> f.u >> f.v >> f.t;
        --f.u;
        --f.v;
    }
    int32_t ans = find_ans(n, e);
    std::cout << ans << '\n';
}

int main() {
    std::ios::sync_with_stdio(false);
    std::cin.tie(nullptr);
    solve_test();
}
