#include <iostream>
#include <vector>
#include <array>
#include <set>
#include <cstdint>

using namespace std;

// a + b sqrt(2)
template <typename T = int64_t>
struct Number {
    T a, b;
    Number() = default;
    Number(T a_) : a(a_), b(0) {}
    Number(T a_, T b_) : a(a_), b(b_) {}

    template <typename U>
    Number(const Number<U> &other) : a(other.a), b(other.b) {}

    Number operator+(const Number &other) const {
        return Number(a + other.a, b + other.b);
    }

    Number operator-(const Number &other) const {
        return Number(a - other.a, b - other.b);
    }

    Number operator*(const Number &other) const {
        return Number(a * other.a + 2 * b * other.b, a * other.b + b * other.a);
    }

    const bool operator<(const Number &other) const {
        return a < other.a || (a == other.a && b < other.b);
    }
    const bool operator==(const Number &other) const {
        return a == other.a && b == other.b;
    }
};

struct Point {
    Number<int64_t> x, y;
    Point() = default;
    Point(const Number<int64_t> &x, const Number<int64_t> &y) : x(x), y(y) {}
    const bool operator<(const Point &other) const {
        return x < other.x || (x == other.x && y < other.y);
    }
    const bool operator==(const Point &other) const {
        return x == other.x && y == other.y;
    }
};

Point operator*(const Number<int64_t> &n, const Point &other) {
    return Point(n * other.x, n * other.y);
}

Point operator+(const Point &p, const Point &other) {
    return Point(p.x + other.x, p.y + other.y);
}

Point apply(int d, Point p) {
    for (int i = 0; i < d; ++i) {
        Point q;
        q.x = Number<int64_t>(0, 1) * p.x - Number<int64_t>(0, 1) * p.y;
        q.y = Number<int64_t>(0, 1) * p.x + Number<int64_t>(0, 1) * p.y;
        q.x.a /= 2;
        q.x.b /= 2;
        q.y.a /= 2;
        q.y.b /= 2;
        p = q;
    }
    return p;
}

vector<pair<Point, Point>> apply_commands(vector<pair<int, int>> commands, Point initial_direction) {
    Point pos = Point(0, 0);
    Point dir = initial_direction;
    vector<pair<Point, Point>> segs;
    for (auto [t, d] : commands) {
        if (t == 0) { // rotate
            dir = apply(d, dir);
        }
        if (t == 1 || t == 2) { // draw / move
            Point next = pos + d * dir;
            if (t == 1) {
                segs.emplace_back(pos, next);
            }
            pos = next;
        }
    }
    return segs;
}

// FIXME INT128
bool collinear(Point p, Point q, Point r) {
    Number<__int128_t> a = Number<__int128_t>(r.x - q.x) * Number<__int128_t>(q.y - p.y);
    Number<__int128_t> b = Number<__int128_t>(r.y - q.y) * Number<__int128_t>(q.x - p.x);
    return a == b;
}

int main() {
    int n; cin >> n;
    vector<pair<int, int>> commands;
    for (int i = 0; i < n; i++) {
        string s; cin >> s;
        int d; cin >> d;
        if (s == "rotate") {
            commands.emplace_back(0, d / 45);
        } else if (s == "draw") {
            commands.emplace_back(1, d);
        } else if (s == "move") {
            commands.emplace_back(2, d);
        }
    }
    Point initial_direction = Point(4, 0);
    vector<pair<Point, Point>> initial_segs = apply_commands(commands, initial_direction);
    int k = initial_segs.size();
    vector<bool> used(k);
    vector<pair<Point, Point>> compressed_initial_segs;
    // TODO: COMPRESS SEGMENTS
    while (!initial_segs.empty()) {
        auto [p, q] = initial_segs.back();
        initial_segs.pop_back();
        bool matched = false;
        for (pair<Point, Point> &other_seg : initial_segs) {
            if (matched) break;
            if (other_seg.first == q) {
                if (collinear(p, q, other_seg.second)) {
                    other_seg = make_pair(p, other_seg.second);
                    matched = true;
                }
            } else if (other_seg.first == p) {
                if (collinear(q, p, other_seg.second)) {
                    other_seg = make_pair(q, other_seg.second);
                    matched = true;
                }
            } else if (other_seg.second == q) {
                if (collinear(p, q, other_seg.first)) {
                    other_seg = make_pair(p, other_seg.first);
                    matched = true;
                }
            } else if (other_seg.second == p) {
                if (collinear(q, p, other_seg.first)) {
                    other_seg = make_pair(q, other_seg.first);
                    matched = true;
                }
            }
        }
        if (!matched) compressed_initial_segs.emplace_back(p, q);
    }
    initial_segs = compressed_initial_segs;
    for (int angle = 1; angle <= 7; ++angle) {
        vector<pair<Point, Point>> new_segs;
        for (auto [p, q] : initial_segs) {
            new_segs.emplace_back(apply(angle, p), apply(angle, q));
        }
        vector<Point> possible_shifts;
        Point r = initial_segs[0].first;
        for (auto [p, q] : new_segs) {
            possible_shifts.push_back(Point(p.x - r.x, p.y - r.y));
            possible_shifts.push_back(Point(q.x - r.x, q.y - r.y));
        }
        set<pair<Point, Point>> new_segs_set(new_segs.begin(), new_segs.end());
        for (Point v : possible_shifts) {
            bool ok = true;
            for (auto [p, q] : initial_segs) {
                if (!ok) break;
                if (new_segs_set.find(make_pair(p + v, q + v)) == new_segs_set.end() &&
                    new_segs_set.find(make_pair(q + v, p + v)) == new_segs_set.end()) {
                    ok = false;
                }
            }
            if (ok) {
                cout << angle * 45 << endl;
                return 0;
            }
        }
    }
    cout << 360 << endl;
}